==> 5.3.1.tar.gz: radare2-5.3.1/COMMUNITY.md <==
# Radare2 community engagement

## Introduction

Over the years, radare2 has grown and grown in terms of source code size,
complexity, features, collaborations, community and more. As a result, it
has become increasingly challenging to manage in a consistent manner.

There exist many different interpretations of problems and solutions.

What might make total sense to one community member may not make sense to
others. The divergence of opinions and ideas can be great for creativity,
collaboration and decision making and rules or conflicts shouldn't be an
excuse to frustrate or make angry contributors.

However, this can also bring its own set of challenges, necessitating we
work together to continue to build an evolving tool that the community
embraces and extends. We wish to provide guidance to the r2 community
(eg. GitHub issues, source code, online chats or conferences) about how
we want to operate.

## What we want to see

We wish to have a supportive community of kind people vibing together,
connected by common interests, which are radare2 and software reverse
engineering in general.

This does not limit to the conversations in our official chat servers,
you can also talk about other things **in the side channel**.

We urge you to respect the personal boundaries of everyone in this
community.

## What we don't want to see

We don't want any form of hate or personal attacks in this community.

We understand that people make mistakes and sometimes don't even know
what they're saying/doing. This is no excuse for intentional harassment,
discriminatory, and abusive behavior.

## What we explicitly tolerate

Mild forms of trolling and non-discriminatory profanity is OK with us.
Interact with each other as you'd interact with a friend, and it will
be well.

## Rule enforcement?

We do not intend to act as policemen, judges, or legislators, and we
don't want to act as enforcers either. We do not want such roles in
the radare2 community, so we will not officially formulate any strict
rules or penalties.

However, we will take action if necessary.

==> 5.7.8.tar.gz: radare2-5.7.8/COMMUNITY.md <==
# Radare2 community engagement

## Introduction

Over the years, radare2 has grown and grown in terms of source code size,
complexity, features, collaborations, community and more. As a result, it
has become increasingly challenging to manage in a consistent manner.

There exist many different interpretations of problems and solutions.

What might make total sense to one community member may not make sense to
others. The divergence of opinions and ideas can be great for creativity,
collaboration and decision making and rules or conflicts shouldn't be an
excuse to frustrate or upset community members.

However, this can also bring its own set of challenges, necessitating we
work together to continue to build an evolving tool that the community
embraces and extends. We wish to provide guidance to the r2 community
(eg. GitHub issues, source code, online chats or conferences) about how
we want to operate.

## What we want to see

We wish to have a supportive community of kind people vibing together,
connected by common interests, which are radare2 and software reverse
engineering in general.

This does not limit to the conversations in our official chat servers,
you can also talk about other things **in the side channel**.

We urge you to respect the personal boundaries of everyone in this
community.

## What we don't want to see

We don't want any form of hate or personal attacks in this community.

We understand that people make mistakes and sometimes don't even know
what they're saying/doing. This is no excuse for intentional harassment,
discriminatory, and abusive behavior.

## What we explicitly tolerate

Mild forms of trolling and non-discriminatory profanity is OK with us.
Interact with each other as you'd interact with a friend, and it will
be well.

## Rule enforcement?

We do not intend to act as policemen, judges, or legislators, and we
don't want to act as enforcers either. We do not want such roles in
the radare2 community, so we will not officially formulate any strict
rules or penalties.

However, we will take action if necessary.
